==========
 Examples
==========

.. _examples:

These files can be found in the docs/source/examples directory of
the git source of this project.  They can also be found in the
`online git repository`_ of this project.

.. _online git repository: http://git.openstack.org/cgit/openstack/oslo.log/tree/doc/source/examples


python_logging.py
-----------------

.. _example_python_logging.py:

.. highlight:: python
.. literalinclude:: examples/python_logging.py
   :linenos:

oslo_logging.py
---------------

.. _example_oslo_logging.py:

.. literalinclude:: examples/oslo_logging.py

usage.py
--------

.. _example_usage.py:

.. literalinclude:: examples/usage.py
   :linenos:

usage_helper.py
---------------

.. _example_usage_helper.py:

.. literalinclude:: examples/usage_helper.py
   :linenos:

usage_i18n.py
-------------

.. _example_usage_i18n.py:

.. literalinclude:: examples/usage_i18n.py
   :linenos:

usage_context.py
----------------

.. _example_usage_context.py:

.. literalinclude:: examples/usage_context.py
   :linenos:
